# DataDockPy Library  

--------------

![Python Versions](https://img.shields.io/badge/python-3.9|3.10|3.11|3.12-blue) 
![License](https://img.shields.io/pypi/l/paystackease.svg) 
![PyPi - Version](https://img.shields.io/pypi/v/paystackease.svg)

<p align="center">    
<a href="https://github.com/DataDock-AI/DataDockPy">
    <img src="media/20241001135438-ezgif.com-video-to-gif-converter.gif" alt="DataDock demo" height="350">
</a>
</p>


## Introduction

DataDockPy is a powerful and user-friendly Python package designed to enhance data analysis. 
It simplifies the extraction and presentation of information from the SEC Edgar database, 
offering enriched data display for SEC form types, form controls, and financial analysis, 
making it an essential tool for professionals working with regulatory filings.

This library uses `Poetry` as a dependency manager.



## Features

- 📁 **Access any SEC filing**: You can access any filings on SEC forms of Form 8-K and Form 10-K
- 📅 **List filings for any date range**: List filings by date e.g. or date range `2024-02-29:2024-03-15`
- 🌟 **User Friendly library**: Uses **[rich](https://rich.readthedocs.io/en/stable/introduction.html) & [tabulate](https://github.com/astanin/python-tabulate)** library to display SEC Edgar data in a beautiful way.
- 🔄 **Page through filings**: Use `filings.next()` and `filings.previous()` to page through filings
- 🏗️ **Filter filings data**: Build data filtering by cik, accession number, form type, filing date
- ✅ **Select a filing**: You can select a filing from the list of filings.
- 🔍 **Preview the text data for a filing**: You can preview the filing (sections) in the terminal or a notebook.
- 📊 **Parse to Dataframe**: You can parse filings to a dataframe.
- 📈 **Financial Statement**: Get financial statements of Form 8-K and Form 10-K of various companies.


## Get Started on Windows/MacOS/Linux Terminal

1. Open your terminal and install poetry using `pip`.
    
    ```commandline
   pip install poetry
   ```
   or

    Install poetry using `pipx`.
    
    ```commandline 
   pipx install poetry
    ```

2. Create a project and clone DataDockPy github repository.

    ```git
    git clone https://github.com/DataDock-AI/DataDockPy.git
    ```

3. Change directory to `DataDockPy`

   ```commandline
   cd DataDockPy
   ```

4. Run the poetry command to install dependencies: 

    ```commandline
   poetry install
   ```

5. Activate virtual environment using poetry: 

    ```commandline
    poetry shell
    ```

6. Set up your SEC_IDENTITY in an `.env` file

   ```dotenv
    SEC_IDENTITY=<your email or usernmae for SEC IDENTITY>
   ```

7. See the following scripts on how to use the package: `run_checks.py` and `run_checks2.py`


## Use DataDockPy with Jupyter

1. Open terminal and install poetry using `pip`.
    
    ```commandline
   pip install poetry
   ```
   or

    Install poetry using `pipx`.
    
    ```commandline 
   pipx install poetry
    ```

2. Create a project and clone `DataDockPy` github repository 

   ```git
    git clone https://github.com/DataDock-AI/DataDockPy.git
    ```

3. Change directory to `DataDockPy`

   ```commandline
   cd DataDockPy
   ```

4. Open your project directory on Anaconda or Visual Studio Code.

5. Choose a python environment (recommended python environment), where poetry was installed. `Ctrl+Shift+P`
6. If asked to install `ipykernel`, see here on installation: [ipykernel installation](https://devinschumacher.com/how-to-setup-jupyter-notebook-virtual-environment-vs-code-kernels/)
7. Check to see if poetry is installed:

   ```bash
   !poetry --version   
   ```

8. Run the poetry command to install dependencies: 

    ```commandline
   poetry install
   ```


## Download DataDockPy Source Code

You can download any of the source codes: `zip` or `tar.gz` here: [DataDockPy Source Code](https://github.com/DataDock-AI/DataDockPy/releases/tag/v0.1.0).


If you have any issue or contribution, please write an issue with this link: https://github.com/DataDock-AI/DataDockPy/issues


